gluster::volume

Enum VolumeType

pub enum VolumeType {
    Arbiter,
    Distribute,
    Stripe,
    Replicate,
    StripedAndReplicate,
    Disperse,
    DistributedAndStripe,
    DistributedAndReplicate,
    DistributedAndStripedAndReplicate,
    DistributedAndDisperse,
}
These are all the different Volume types that are possible in Gluster Note: Tier is not represented here because I’m waiting for it to become more stable For more information about these types see: [Gluster Volume] (https://gluster.readthedocs. org/en/latest/Administrator%20Guide/Setting%20Up%20Volumes/)

Variants



Arbiter



Distribute



Stripe



Replicate



StripedAndReplicate



Disperse



DistributedAndStripe



DistributedAndReplicate



DistributedAndStripedAndReplicate



DistributedAndDisperse

Implementations

Source

impl VolumeType

pub fn new(name: &str) -> VolumeType

Constructs a new VolumeType from a &str

pub fn from_str(vol_type: &str) -> VolumeType

Returns a enum variant of the given String.

pub fn to_string(&self) -> String

Returns a String representation of the selected enum variant.