pub enum VolumeType {
Arbiter,
Distribute,
Stripe,
Replicate,
StripedAndReplicate,
Disperse,
DistributedAndStripe,
DistributedAndReplicate,
DistributedAndStripedAndReplicate,
DistributedAndDisperse,
}Expand description
These are all the different Volume types that are possible in Gluster Note: Tier is not represented here because I’m waiting for it to become more stable For more information about these types see: [Gluster Volume] (https://gluster.readthedocs. org/en/latest/Administrator%20Guide/Setting%20Up%20Volumes/)
Variants
Arbiter
Distribute
Stripe
Replicate
StripedAndReplicate
Disperse
DistributedAndStripe
DistributedAndReplicate
DistributedAndStripedAndReplicate
DistributedAndDisperse
Implementations
Sourceimpl VolumeType
impl VolumeType